pub enum StdError {
Api(ApiError),
Io(IoError),
NoResolvedAddress,
InvalidSocketAddress,
InvalidSocketPort,
MissingDestinationAddress,
RecursiveDirectoryCreationUnsupported,
ThreadResultUnavailable,
NoAvailableCpu,
}Expand description
Errors owned by the ArceOS standard-library facade.
Variants
Api(ApiError)
A public ArceOS API operation failed.
Io(IoError)
An ax-io operation failed while implementing a standard-library action.
NoResolvedAddress
Address resolution yielded no usable socket address.
InvalidSocketAddress
A socket address string has invalid syntax.
InvalidSocketPort
A socket port string is not a valid u16 value.
MissingDestinationAddress
A datagram send operation has no destination address.
RecursiveDirectoryCreationUnsupported
Recursive directory creation is not implemented by this facade.
A joined task exited without publishing its return value.
NoAvailableCpu
The runtime reported no available CPU.