Module prelude

Module prelude 

The I/O Prelude.

The purpose of this module is to alleviate imports of many common I/O traits by adding a glob import to the top of I/O heavy modules:

use ax_io::prelude::*;

Traits

BufRead
A BufRead is a type of Reader which has an internal buffer, allowing it to perform extra ways of reading.
IoBuf
A trait for byte buffers that can be used as a source of bytes to read.
IoBufExt
Extension methods for IoBuf.
IoBufMut
A trait for byte buffers that can be used as a destination for bytes to write.
IoBufMutExt
Extension methods for IoBufMut.
Read
The Read trait allows for reading bytes from a source.
Seek
The Seek trait provides a cursor which can be moved within a stream of bytes.
Write
A trait for objects which are byte-oriented sinks.