BufReader

Struct BufReader 

pub struct BufReader<R>
where R: ?Sized,
{ /* private fields */ }
The BufReader<R> struct adds buffering to any reader.

See [std::io::BufReader] for more details.

Implementations

Source

impl<R> BufReader<R>
where R: Read,

pub fn with_capacity(capacity: usize, inner: R) -> BufReader<R>

Creates a new BufReader<R> with the specified buffer capacity.

pub fn new(inner: R) -> BufReader<R>

Creates a new BufReader<R> with a default buffer capacity.

Source

impl<R> BufReader<R>
where R: ?Sized,

pub fn get_ref(&self) -> &R

Gets a reference to the underlying reader.

It is inadvisable to directly read from the underlying reader.

pub fn get_mut(&mut self) -> &mut R

Gets a mutable reference to the underlying reader.

It is inadvisable to directly read from the underlying reader.

pub fn buffer(&self) -> &[u8]

Returns a reference to the internally buffered data.

Unlike fill_buf, this will not attempt to fill the buffer if it is empty.

pub fn capacity(&self) -> usize

Returns the number of bytes the internal buffer can hold at once.

pub fn into_inner(self) -> R

Unwraps this BufReader<R>, returning the underlying reader.

Note that any leftover data in the internal buffer is lost. Therefore, a following read from the underlying reader may lead to data loss.

Source

impl<R> BufReader<R>
where R: Read + ?Sized,

pub fn peek(&mut self, n: usize) -> Result<&[u8], AxError>

Attempt to look ahead n bytes.

n must be less than or equal to capacity.

The returned slice may be less than n bytes long if end of file is reached.

After calling this method, you may call consume with a value less than or equal to n to advance over some or all of the returned bytes.