Stdout

Struct Stdout 

pub struct Stdout { /* private fields */ }
A handle to the global standard output stream of the current process.

Implementations

Source

impl Stdout

pub fn lock(&self) -> StdoutLock<'static>

Locks this handle to the standard output stream, returning a writable guard.

The lock is released when the returned lock goes out of scope. The returned guard also implements the Write trait for writing data.