IrqSafeMutex

Struct IrqSafeMutex 

pub struct IrqSafeMutex<T: ?Sized>(/* private fields */);
A mutex that disables preemption and local interrupts while held.

Implementations

Source

impl<T> IrqSafeMutex<T>

pub const fn new(value: T) -> Self

Creates an unlocked IRQ-safe mutex.

pub fn lock(&self) -> IrqSafeMutexGuard<'_, T>

Acquires the lock after saving and disabling local interrupts.

pub fn try_lock(&self) -> Option<IrqSafeMutexGuard<'_, T>>

Attempts to acquire the lock with IRQ-save semantics.