pub type NoPreemptMutex<T> = RawSpinLock<T>;Expand description
A mutex that disables preemption while held.
Callers must ensure the lock is not used by an interrupt handler.
Aliased Type
pub struct NoPreemptMutex<T>(/* private fields */);pub type NoPreemptMutex<T> = RawSpinLock<T>;A mutex that disables preemption while held.
Callers must ensure the lock is not used by an interrupt handler.
pub struct NoPreemptMutex<T>(/* private fields */);