Module sync

Module sync 

Useful synchronization primitives.

Re-exports

pub use core::sync::atomic;

Functions

dump_lockdep_trace
Dumps the buffered phase-3 trace stream to the raw trace sink.
set_lockdep_trace_enabled
Enables or disables the phase-3 lock flow tracing path.

Type Aliases

MutexNon-multitask
A raw spin lock that does nothing while trying to lock.
MutexGuardNon-multitask
A guard that provides mutable data access for SpinRaw.