Builder

Struct Builder 

pub struct Builder { /* private fields */ }
Thread factory, which can be used in order to configure the properties of a new thread.

Methods can be chained on it in order to configure it.

Implementations

Source

impl Builder

pub const fn new() -> Builder

Generates the base configuration for spawning a thread, from which configuration methods can be chained.

pub fn name(self, name: String) -> Builder

Names the thread-to-be.

pub fn stack_size(self, size: usize) -> Builder

Sets the size of the stack (in bytes) for the new thread.

pub fn spawn<F, T>(self, f: F) -> StdResult<JoinHandle<T>>
where F: FnOnce() -> T + Send + 'static, T: Send + 'static,

Spawns a new thread by taking ownership of the Builder, and returns an StdResult to its JoinHandle.

The spawned thread may outlive the caller (unless the caller thread is the main thread; the whole process is terminated when the main thread finishes). The join handle can be used to block on termination of the spawned thread.