pub struct JoinHandle<T> { /* private fields */ }Expand description
An owned permission to join on a thread (block on its termination).
A JoinHandle detaches the associated thread when it is dropped, which
means that there is no longer any handle to the thread and no way to join
on it.
Implementations