Crate ax_std

Crate ax_std 

The ArceOS Standard Library

The ArceOS Standard Library is a mini-std library, with an interface similar to rust std, but calling the functions directly in ArceOS modules, instead of using libc and system calls.

Cargo Features

  • CPU
    • smp: Enable SMP (symmetric multiprocessing) support.
    • fp-simd: Enable floating point and SIMD support.
  • Interrupts:
    • Interrupt handling is always available.
  • Memory
    • alloc: Enable dynamic memory allocation.
    • paging: Enable page table manipulation.
    • tls: Enable thread-local storage.
  • Task management
    • Multi-threading and timer-driven scheduling are always available.
  • Upperlayer stacks
    • fs: Enable file system support.
    • ext4fs: Enable the ext4 filesystem.
    • fatfs: Enable the FAT filesystem.
    • net: Enable networking support.
    • dns: Enable DNS lookup support.
    • display: Enable graphics support.
  • Device drivers are selected directly through ax-driver/* features by board configurations.

Re-exports

pub use alloc::boxed;alloc
pub use alloc::collections;alloc
pub use alloc::format;alloc
pub use alloc::string;alloc
pub use alloc::vec;alloc
pub use alloc::vec;alloc
pub use core::arch;
pub use core::cell;
pub use core::cmp;
pub use core::hint;
pub use core::marker;
pub use core::mem;
pub use core::ops;
pub use core::ptr;
pub use core::slice;
pub use core::str;

Modules

env
Inspection and manipulation of the process’s environment.
io
Traits, helpers, and type definitions for core I/O functionality.
os
OS-specific functionality.
process
A module for working with processes.
sync
Useful synchronization primitives.
thread
Native threads.
time
Temporal quantification.

Macros

print
Prints to the standard output.
println
Prints to the standard output, with a newline.

Enums

StdError
Errors owned by the ArceOS standard-library facade.

Type Aliases

StdResult
A result returned by an ArceOS standard-library facade operation.