docs.rs failed to build ax-std-0.5.24
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build:
ax-std-0.5.15
The ArceOS Standard Library
The ArceOS Standard Library is a mini-std library, with an interface similar to rust [std], but calling the functions directly in ArceOS modules, instead of using libc and system calls.
Cargo Features
- CPU
smp: Enable SMP (symmetric multiprocessing) support.fp-simd: Enable floating point and SIMD support.
- Interrupts:
irq: Enable interrupt handling support.
- Memory
alloc: Enable dynamic memory allocation.paging: Enable page table manipulation.tls: Enable thread-local storage.
- Task management
multitask: Enable multi-threading support.sched-rr: Use the Round-robin preemptive scheduler.sched-cfs: Use the Completely Fair Scheduler (CFS) preemptive scheduler.
- Upperlayer stacks
fs: Enable file system support.ext4fs: Enable the ext4 filesystem.fatfs: Enable the FAT filesystem.net: Enable networking support.dns: Enable DNS lookup support.display: Enable graphics support.
- Device drivers are selected directly through
ax-driver/*features by board configurations.