Stdin

Struct Stdin 

pub struct Stdin { /* private fields */ }
A handle to the standard input stream of a process.

Implementations

Source

impl Stdin

pub fn lock(&self) -> StdinLock<'static>

Locks this handle to the standard input stream, returning a readable guard.

The lock is released when the returned lock goes out of scope. The returned guard also implements the Read and BufRead traits for accessing the underlying data.