pub trait BufRead: Read {
// Required methods
fn fill_buf(&mut self) -> Result<&[u8], AxError>;
fn consume(&mut self, amount: usize);
// Provided methods
fn has_data_left(&mut self) -> Result<bool, AxError> { ... }
fn skip_until(&mut self, byte: u8) -> Result<usize, AxError> { ... }
}Expand description
A BufRead is a type of Reader which has an internal buffer, allowing it
to perform extra ways of reading.
See [std::io::BufRead] for more details.
Required Methods
Provided Methods
Sourcefn has_data_left(&mut self) -> Result<bool, AxError>
fn has_data_left(&mut self) -> Result<bool, AxError>
Checks if there is any data left to be read.