pub struct IrqSafeMutex<T: ?Sized>(/* private fields */);Expand description
A mutex that disables preemption and local interrupts while held.
Implementations
Sourceimpl<T> IrqSafeMutex<T>
impl<T> IrqSafeMutex<T>
Sourcepub fn lock(&self) -> IrqSafeMutexGuard<'_, T>
pub fn lock(&self) -> IrqSafeMutexGuard<'_, T>
Acquires the lock after saving and disabling local interrupts.
Sourcepub fn try_lock(&self) -> Option<IrqSafeMutexGuard<'_, T>>
pub fn try_lock(&self) -> Option<IrqSafeMutexGuard<'_, T>>
Attempts to acquire the lock with IRQ-save semantics.