JoinHandle

Struct JoinHandle 

pub struct JoinHandle<T> { /* private fields */ }
An owned permission to join on a thread (block on its termination).

A JoinHandle detaches the associated thread when it is dropped, which means that there is no longer any handle to the thread and no way to join on it.

Implementations

Source

impl<T> JoinHandle<T>

pub fn thread(&self) -> &Thread

Extracts a handle to the underlying thread.

pub fn join(self) -> StdResult<T>

Waits for the associated thread to finish.

This function will return immediately if the associated thread has already finished.